#ifndef __EGG_INTL_H__
#define __EGG_INTL_H__

#include <config.h>
#include <glib/gi18n.h>

#endif /* __EGG_INTL_H__ */
